@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-certificates-extension.c 1638 2007-11-04 19:34:30Z cosimoc $
+ *  $Id$
  */
 
 #include "config.h"
@@ -32,15 +32,7 @@
 #include <epiphany/ephy-embed-shell.h>
 #include <epiphany/ephy-statusbar.h>
 
-#include <gtk/gtkaction.h>
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkframe.h>
-#include <gtk/gtkrc.h>
-#include <gtk/gtkeventbox.h>
-#include <gtk/gtkwindow.h>
+#include <gtk/gtk.h>
 #include <gmodule.h>
 #include <glib/gi18n-lib.h>
 
